@@ -4,7 +4,16 @@ import os
 import stat
 from contextlib import contextmanager
 from io import BytesIO, StringIO
-from typing import Callable, Iterable, List, Mapping, Optional, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Callable,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+    Tuple,
+    Union,
+)
 
 from funcy import cached_property
 
@@ -17,6 +26,16 @@ from .base import BaseGitBackend
 logger = logging.getLogger(__name__)
 
 
+if TYPE_CHECKING:
+    from dvc.types import StrPath
+
+
+# NOTE: constant from libgit2 git2/checkout.h
+# This can be removed after next pygit2 release:
+# see https://github.com/libgit2/pygit2/pull/1087
+GIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES = 1 << 18
+
+
 class Pygit2Object(GitObject):
     def __init__(self, obj):
         self.obj = obj
@@ -39,6 +58,14 @@ class Pygit2Object(GitObject):
             return stat.S_IFDIR
         return self.obj.filemode
 
+    @property
+    def size(self) -> int:
+        return len(self.obj.read_raw())
+
+    @property
+    def sha(self) -> str:
+        return self.obj.hex
+
     def scandir(self) -> Iterable["Pygit2Object"]:
         for entry in self.obj:  # noqa: B301
             yield Pygit2Object(entry)
@@ -81,6 +108,15 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
 
         return RefdbFsBackend(self.repo)
 
+    def _resolve_refish(self, refish: str):
+        from pygit2 import GIT_OBJ_COMMIT, Tag
+
+        commit, ref = self.repo.resolve_refish(refish)
+        if isinstance(commit, Tag):
+            ref = commit
+            commit = commit.peel(GIT_OBJ_COMMIT)
+        return commit, ref
+
     @property
     def default_signature(self):
         try:
@@ -90,6 +126,16 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
                 "Git username and email must be configured"
             ) from exc
 
+    @staticmethod
+    def _get_checkout_strategy(strategy: Optional[int] = None):
+        from pygit2 import GIT_CHECKOUT_RECREATE_MISSING, GIT_CHECKOUT_SAFE
+
+        if strategy is None:
+            strategy = GIT_CHECKOUT_SAFE | GIT_CHECKOUT_RECREATE_MISSING
+        if os.name == "nt":
+            strategy |= GIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES
+        return strategy
+
     # Workaround to force git_backend_odb_pack to release open file handles
     # in DVC's mixed git-backend environment.
     # See https://github.com/iterative/dvc/issues/5641
@@ -129,21 +175,23 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
     ):
         from pygit2 import GIT_CHECKOUT_FORCE, GitError
 
-        checkout_strategy = GIT_CHECKOUT_FORCE if force else None
+        strategy = self._get_checkout_strategy(
+            GIT_CHECKOUT_FORCE if force else None
+        )
 
         with self.release_odb_handles():
             if create_new:
                 commit = self.repo.revparse_single("HEAD")
                 new_branch = self.repo.branches.local.create(branch, commit)
-                self.repo.checkout(new_branch, strategy=checkout_strategy)
+                self.repo.checkout(new_branch, strategy=strategy)
             else:
                 if branch == "-":
                     branch = "@{-1}"
                 try:
-                    commit, ref = self.repo.resolve_refish(branch)
+                    commit, ref = self._resolve_refish(branch)
                 except (KeyError, GitError):
                     raise RevError(f"unknown Git revision '{branch}'")
-                self.repo.checkout_tree(commit, strategy=checkout_strategy)
+                self.repo.checkout_tree(commit, strategy=strategy)
                 detach = kwargs.get("detach", False)
                 if ref and not detach:
                     self.repo.set_head(ref.name)
@@ -200,7 +248,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
         from pygit2 import GitError
 
         try:
-            commit, _ref = self.repo.resolve_refish(rev)
+            commit, _ref = self._resolve_refish(rev)
             return str(commit.id)
         except (KeyError, GitError):
             pass
@@ -220,7 +268,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
         from pygit2 import GitError
 
         try:
-            commit, _ref = self.repo.resolve_refish(rev)
+            commit, _ref = self._resolve_refish(rev)
         except (KeyError, GitError):
             raise SCMError(f"Invalid commit '{rev}'")
         return GitCommit(
@@ -234,7 +282,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
     def _get_stash(self, ref: str):
         raise NotImplementedError
 
-    def is_ignored(self, path: str) -> bool:
+    def is_ignored(self, path: "StrPath") -> bool:
         rel = relpath(path, self.root_dir)
         if os.name == "nt":
             rel.replace("\\", "/")
@@ -294,12 +342,12 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
         from pygit2 import GitError
 
         def _contains(repo, ref, search_commit):
-            commit, _ref = self.repo.resolve_refish(ref)
+            commit, _ref = self._resolve_refish(ref)
             base = repo.merge_base(search_commit.id, commit.id)
             return base == search_commit.id
 
         try:
-            search_commit, _ref = self.repo.resolve_refish(rev)
+            search_commit, _ref = self._resolve_refish(rev)
         except (KeyError, GitError):
             raise SCMError(f"Invalid rev '{rev}'")
 
@@ -362,11 +410,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
         return str(oid), False
 
     def _stash_apply(self, rev: str):
-        from pygit2 import (
-            GIT_CHECKOUT_RECREATE_MISSING,
-            GIT_CHECKOUT_SAFE,
-            GitError,
-        )
+        from pygit2 import GitError
 
         from dvc.scm.git import Stash
 
@@ -374,8 +418,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
             try:
                 self.repo.index.read(False)
                 self.repo.stash_apply(
-                    index,
-                    strategy=GIT_CHECKOUT_SAFE | GIT_CHECKOUT_RECREATE_MISSING,
+                    index, strategy=self._get_checkout_strategy()
                 )
             except GitError as exc:
                 raise MergeConflictError(
@@ -384,7 +427,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
 
         # libgit2 stash apply only accepts refs/stash items by index. If rev is
         # not in refs/stash, we will push it onto the stash, and then pop it
-        commit, _ref = self.repo.resolve_refish(rev)
+        commit, _ref = self._resolve_refish(rev)
         stash = self.repo.references.get(Stash.DEFAULT_STASH)
         if stash:
             for i, entry in enumerate(stash.log()):
@@ -459,6 +502,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
 
         if ours or theirs:
             strategy |= GIT_CHECKOUT_ALLOW_CONFLICTS
+        strategy = self._get_checkout_strategy(strategy)
 
         index = self.repo.index
         if paths:
@@ -475,7 +519,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
 
         with self.release_odb_handles():
             self.repo.checkout_index(
-                index=index, paths=path_list, strategy=strategy,
+                index=index, paths=path_list, strategy=strategy
             )
 
             if index.conflicts and (ours or theirs):
@@ -539,3 +583,6 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
                 self.repo.state_cleanup()
                 self.repo.index.write()
         return None
+
+    def validate_git_remote(self, url: str):
+        raise NotImplementedError
